/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect, memo} from 'react'
import styled from 'styled-components'
import FormControl from '@material-ui/core/FormControl';
import {ObjTypeBox, StyledFormLabel} from '../StyledComponents.js'
import RadioGroup from '@material-ui/core/RadioGroup';
import Radio from '@material-ui/core/Radio';
import {GetSubjectIconByName} from '../GetIconByName.js'
import FormControlLabel from '@material-ui/core/FormControlLabel';
import axios from 'axios'
import {apiUrl, apiDomain} from '../../../env';

function Licenca (props) {

    const options = [
        {name : "CC BY", description : "(Esta licença permite que outros distribuam, remixem, adaptem e criem a partir do seu trabalho, mesmo para fins comerciais, desde que lhe atribuam o devido crédito pela criação original)", id : 1},

        {name : "CC BY-SA", description : "(Esta licença permite que outros remixem, adaptem e criem a partir do seu trabalho, mesmo para fins comerciais, desde que lhe atribuam o devido crédito e que licenciem as novas criações sob termos idênticos)", id : 2},

        {name : "CC BY-NC", description : "(Esta licença permite que outros remixem, adaptem e criem a partir do seu trabalho para fins não comerciais e, embora os novos trabalhos tenham de lhe atribuir o devido crédito e não possam ser usados para fins comerciais, os usuários não têm de licenciar esses trabalhos derivados sob os mesmos termos)", id : 4},

        {name : "CC BY-NC SA", description : "(Esta licença permite que outros remixem, adaptem e criem a partir do seu trabalho para fins não comerciais, desde que atribuam o devido crédito e que licenciem as novas criações sob termos idênticos)", id : 5},

        {name : "CC BY-NC-ND 3.0 BR", description : "(Atribuição-NãoComercial-SemDerivações 3.0 Brasil. Esta licença permite compartilhar, copiar e redistribuir o material em qualquer suporte ou formato)", id : 12}
    ]

    const [value, setValue] = useState(-1)
    const handleChange = (event) => {setValue(Number(event.target.value))}

    return (
        <FormControl required="true" style={{width : "100%"}}>
            <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                <b>Licença do Uso do Conteúdo</b> <a href="https://br.creativecommons.org/licencas/" style={{color : "#ff7f00", textDecoration : "underline"}}>Saiba mais</a>
            </StyledFormLabel>
            <StyledFormControlLabel aria-label="Tipo de Recurso" name="Tipo de Recurso" row value={value} onChange={handleChange} style={{justifyContent : "center"}}>
                {
                    options.map( (option) =>
                    <FormControlLabel key={option.id} value={option.id}
                        control={<Radio />}
                        label={
                            <span className="title">{option.name}
                            <span className="parentese"> {option.description}</span>
                            </span>
                            }
                        />
                    )

                }
            </StyledFormControlLabel>
        </FormControl>
    )
}

export default memo(Licenca)

const StyledFormControlLabel = styled(RadioGroup)`
    .MuiFormControlLabel-root {
            display : block !important;
            margin-bottom : 16px !important;
    }

    .title {
        font-size: 14px;
        font-weight: 600;
        color:#666;
        padding-left: 2px;
    }
    .parentese {
        font-weight: 200;
        color:#a5a5a5;
        padding-left: 10px;
    }
`
