/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect, memo} from 'react'
import { makeStyles } from '@material-ui/core/styles';
import FormControl from '@material-ui/core/FormControl';
import {ObjTypeBox, StyledFormLabel} from '../StyledComponents.js'
import RadioGroup from '@material-ui/core/RadioGroup';
import Radio from '@material-ui/core/Radio';
import {GetSubjectIconByName} from '../GetIconByName.js'
import FormControlLabel from '@material-ui/core/FormControlLabel';
import axios from 'axios'
import {apiUrl, apiDomain} from '../../../env';

const useStyles = makeStyles({
  root: {
    '&:hover': {
      backgroundColor: 'transparent',
    },
}})

function StyledRadio (props) {
    const classes = useStyles();
    return (
        <Radio
            className={classes.root}
            disableRipple
            checkedIcon = {
                <ObjTypeBox checked>
                    <span>
                        {GetSubjectIconByName(props.label)}
                        <p>{props.label}</p>
                    </span>
                </ObjTypeBox>
            }
            icon = {
                <ObjTypeBox>
                    <span>
                        {GetSubjectIconByName(props.label)}
                        <p>{props.label}</p>
                    </span>
                </ObjTypeBox>
            }
            {...props}
        />
    )
}

function OutrasTematicas (props) {

    const [value, setValue] = useState(-1)
    const handleChange = (event) => {setValue(Number(event.target.value))}

    return (
        <FormControl style={{width : "100%"}}>
            <StyledFormLabel component="legend" style={{fontSize : "14px", marginBottom : "10px"}}>
                <b>Outras Temáticas</b>
            </StyledFormLabel>
            <RadioGroup aria-label="Tipo de Recurso" name="Tipo de Recurso" row value={value} onChange={handleChange} style={{justifyContent : "center"}}>
                {
                    props.subjects.map( (subject) =>
                    <FormControlLabel key={subject.id} value={subject.id}
                        control={<StyledRadio label={subject.name} checked={value === subject.id}/>}
                        />
                    )

                }
            </RadioGroup>
        </FormControl>
    )
}

export default memo(OutrasTematicas)
